@@ -1,6 +1,6 @@
 #!/usr/bin/perl -Tw
 
-# $Id: Hash.pm,v 1.9 2008-07-07 15:20:59 ian Exp $
+# $Id: Hash.pm 1509 2010-08-21 23:10:21Z ian $
 package Class::Declare::Hash;
 
 use strict;
@@ -20,7 +20,7 @@ L<Class::Declare>, providing the B<hash()> routine.
 use base  qw( Class::Declare     );
 use vars  qw( $REVISION $VERSION );
 
-  $REVISION = '$Revision: 1.9 $';
+  $REVISION = '$Revision: 1509 $';
   $VERSION  = Class::Declare->VERSION;
 
 
@@ -52,7 +52,7 @@ L<Class::Declare>-derived object or package.
   # give access to the %__ATTR__, %__FRIEND__ and %__DEFN__ hashes of
   # Class::Declare. See the comment in Class::Declare::hash() for an
   # explanation.
-  sub __init__ : locked method
+  sub __init__ : method
   {
     my  $class  = __PACKAGE__->class( shift );
     # what's our method name?
@@ -261,10 +261,14 @@ L<Class::Declare>-derived object or package.
     };  # $__hash__()
 
 
+# jump into the Class::Declare namespace to create the dump() routine
+package Class::Declare;
+
+
 # hash()
 #
 # Generate a textual representation of the object/class
-sub hash : locked method
+sub hash : method
 {
   my  $self   = Class::Declare->class( shift );
   my  $class  = ref( $self ) || $self;
